using System.Text.Json;
using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service;

public class QuizServiceStub: IQuizServiceJson
{
    private readonly string _jsonFilePath =
        Path.Combine(Environment.CurrentDirectory, "wwwroot", "fake_data_quiz.json");

    public async Task<List<Quiz>> getQuizzesJson()
    {
        if (!File.Exists(_jsonFilePath))
        {
            Console.Out.WriteLine($"{_jsonFilePath} not found");
            return new List<Quiz>();
        }

        var json = await File.ReadAllTextAsync(_jsonFilePath);
        return JsonSerializer.Deserialize<List<Quiz>>(json) ?? new List<Quiz>();
    }

    public async Task<List<Quiz>> getQuizzesToValidateJson()
    {
        var quizzes = await getQuizzesJson();
        return quizzes.Where(quiz => quiz.IsValid == false).ToList();;
    }

    public async Task removeQuizJson(int id)
    {
        var data = await getQuizzesJson();
        var quiz = data.FirstOrDefault(q => q.Id == id);
        if (quiz != null)
        {
            data.Remove(quiz);
            await saveQuizJson(data);
        }
    }

    public async Task updateQuizJson(Quiz quiz)
    {
        var data = await getQuizzesJson();
        var existingQuiz = data.FirstOrDefault(q => q.Id == quiz.Id);
        if (existingQuiz != null)
        {
            existingQuiz.Question = quiz.Question;
            existingQuiz.AnswerA = quiz.AnswerA;
            existingQuiz.AnswerB = quiz.AnswerB;
            existingQuiz.AnswerC = quiz.AnswerC;
            existingQuiz.AnswerD = quiz.AnswerD;
            existingQuiz.CAnswer = quiz.CAnswer;
            existingQuiz.IsValid = quiz.IsValid;
            existingQuiz.UserProposition = quiz.UserProposition;
            await saveQuizJson(data);
        }
    }
    
    public async Task saveQuizJson(List<Quiz> quizzes)
    {
        var json = JsonSerializer.Serialize(quizzes, new JsonSerializerOptions { WriteIndented = true });
        await File.WriteAllTextAsync(_jsonFilePath, json);
    }
}
