using System.Text.Json;
using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service;

    public class QuoteServiceStub : IQuoteService
    {
    private readonly string _jsonFilePath = Path.Combine(Environment.CurrentDirectory, "wwwroot", "fake-dataQuote.json");

        public async Task saveQuoteJson(List<Quote> quotes)
        {
            var json = JsonSerializer.Serialize(quotes, new JsonSerializerOptions { WriteIndented = true });
            await File.WriteAllTextAsync(_jsonFilePath, json);
        }

        public async Task addQuote(Quote quote)
        {
            var data = await getAllQuote();
            quote.Id = data.Count > 0 ? data.Max(p => p.Id) + 1 : 1;
            data.Add(quote);
            await saveQuoteJson(data);
    }

        public async Task removeQuote(Quote quote)
        {
            var data = await getAllQuote();
            var q = data.FirstOrDefault(p => p.Id == quote.Id);
            if (q != null)
            {
                data.Remove(q);
                await saveQuoteJson(data);
            }
        }

        public async Task validQuote(Quote quote)
        {
            throw new NotImplementedException();
        }

        public async Task updateQuote(Quote quote)
        {
            var data = await getAllQuote();
            var q = data.FirstOrDefault(p => p.Id == quote.Id);
            if (q != null)
            {
                q.Content = quote.Content;
                q.Charac = quote.Charac;
                q.ImgPath = quote.ImgPath;
                q.TitleSrc = quote.TitleSrc;
                q.DateSrc = quote.DateSrc;
                q.Langue = quote.Langue;
                await saveQuoteJson(data);
            }
        }

        public async Task<List<Quote>> getAllQuote()
        {
            if (!File.Exists(_jsonFilePath))
            {
                Console.Out.WriteLine($"{_jsonFilePath} not found");
                return new List<Quote>();
            }

            var json = await File.ReadAllTextAsync(_jsonFilePath);
            return JsonSerializer.Deserialize<List<Quote>>(json) ?? new List<Quote>();
        }

        public async Task<List<Quote>> getSomeQuote(int nb, int page)
        {
            var quotes = await getAllQuote();
            if((page - 1) * nb + nb > quotes.Count())
            {
                return quotes.GetRange(quotes.Count()-nb, nb);
            }
            return quotes.GetRange((page - 1) * nb, nb);
        }

        public  async Task<Quote> getOnequote(int id)
        {
            var data = await getAllQuote();
            var q = data.FirstOrDefault(p => p.Id == id);
            if (q != null)
            {
                return q;
            }
            return null;
        }

        public async Task<List<Quote>> reserchQuote(string reserch, List<string> argument)
        {
            throw new NotImplementedException();
        }

        public async Task<List<Quote>> getAllQuoteInvalid()
        {
            throw new NotImplementedException();
        }

        public async Task<List<Quote>> getSomeQuoteInvalid(int nb, int page)
        {
            throw new NotImplementedException();
        }

        public async Task<int> getNbQuote()
        {
            var data = await getAllQuote();
            return data.Count; 
        }
}  
   